@@ -59,15 +59,15 @@ def get_args():
     arg.add_argument("--preview", action="store_true",
                      help="Print the current color palette.")
 
+    arg.add_argument("--vte", action="store_true",
+                     help="Fix text-artifacts printed in VTE terminals.")
+
     arg.add_argument("-c", action="store_true",
                      help="Delete all cached colorschemes.")
 
     arg.add_argument("-i", metavar="\"/path/to/img.jpg\"",
                      help="Which image or directory to use.")
 
-    arg.add_argument("-g", action="store_true",
-                     help="Generate an oomox theme.")
-
     arg.add_argument("-l", action="store_true",
                      help="Generate a light colorscheme.")
 
@@ -177,7 +177,7 @@ def parse_args(parser):
     if not args.n:
         wallpaper.change(colors_plain["wallpaper"])
 
-    sequences.send(colors_plain, to_send=not args.s)
+    sequences.send(colors_plain, to_send=not args.s, vte_fix=args.vte)
 
     if sys.stdout.isatty():
         colors.palette()
@@ -192,7 +192,6 @@ def parse_args(parser):
             util.disown([cmd])
 
     if not args.e:
-        reload.oomox(args.g)
         reload.gtk()
 
 
